--- loncom/publisher/lonpubdir.pm	2011/11/14 00:20:31	1.137
+++ loncom/publisher/lonpubdir.pm	2014/01/21 18:23:35	1.149
@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Construction Space Directory Lister
 #
-# $Id: lonpubdir.pm,v 1.137 2011/11/14 00:20:31 raeburn Exp $
+# $Id: lonpubdir.pm,v 1.149 2014/01/21 18:23:35 musolffc Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -33,7 +33,6 @@ use strict;
 use Apache::File;
 use File::Copy;
 use Apache::Constants qw(:common :http :methods);
-use Apache::loncacc;
 use Apache::loncommon();
 use Apache::lonhtmlcommon();
 use Apache::londiff();
@@ -47,12 +46,12 @@ sub handler {
 
   my $r=shift;
 
-  # Validate access to the construction space and get username@domain.
+  # Validate access to the construction space and get username:domain.
 
   my $uname;
   my $udom;
 
-  ($uname,$udom)=&Apache::loncacc::constructaccess($r->uri); 
+  ($uname,$udom)=&Apache::lonnet::constructaccess($r->uri); 
   unless (($uname) && ($udom)) {
      return HTTP_NOT_ACCEPTABLE;
   }
@@ -98,6 +97,7 @@ sub handler {
   opendir(DIR,$fn);
   my @files=sort {uc($a) cmp uc($b)} (readdir(DIR));
   foreach my $filename (@files) {
+     next if ($filename eq '.DS_Store');
      my ($cdev,$cino,$cmode,$cnlink,
          $cuid,$cgid,$crdev,$csize,
          $catime,$cmtime,$cctime,
@@ -144,20 +144,28 @@ sub startpage {
 
     &Apache::lonhtmlcommon::clear_breadcrumbs();
     &Apache::lonhtmlcommon::add_breadcrumb({
-        'text'  => 'Construction Space',
+        'text'  => 'Authoring Space',
         'href'  => &Apache::loncommon::authorspace($formaction),
     });
     # breadcrumbs (and tools) will be created 
     # in start_page->bodytag->innerregister
 
     $env{'request.noversionuri'}=$formaction;
-    $r->print(&Apache::loncommon::start_page('Construction Space',undef));
+    $r->print(&Apache::loncommon::start_page('Authoring Space',undef));
+
+    my $londocroot = $Apache::lonnet::perlvar{'lonDocRoot'};
+    my $current_disk_usage = &Apache::lonnet::diskusage($udom,$uname,"$londocroot/priv/$udom/$uname");
+    my $disk_quota = &Apache::loncommon::get_user_quota($uname,$udom,'author'); #expressed in Mb
+    $disk_quota = 1000 * $disk_quota; # convert from Mb to kb
 
     $r->print(&Apache::loncommon::head_subbox(
-                &Apache::loncommon::CSTR_pageheader()));
+                     '<div style="float:right;padding-top:0;margin-top;0">'
+                    .&Apache::lonhtmlcommon::display_usage($current_disk_usage,$disk_quota)
+                    .'</div>'
+                    .&Apache::loncommon::CSTR_pageheader()));
 
     my $esc_thisdisfn = &Apache::loncommon::escape_single($thisdisfn);
-    my $doctitle = 'LON-CAPA '.&mt('Construction Space');
+    my $doctitle = 'LON-CAPA '.&mt('Authoring Space');
     my $newname = &mt('New Name');
     my $pubdirscript=(<<ENDPUBDIRSCRIPT);
 <script type="text/javascript">
@@ -458,11 +466,12 @@ sub putdirectory {
     my $disfilename = $dirname;
 # Don't display directory itself, and there is no way up from root directory
     unless ((($dirname eq '..') && ($reqfile=~/^\/[^\/]+\/[^\/]+$/)) || ($dirname eq '.')) {
-	my $kaputt=0;
+        my $kaputt=0;
         if (ref($bombs) eq 'HASH') {
-	    foreach my $key (keys(%{$bombs})) {
-	        if ($key =~ m{^\Q$targetdir/$disfilename\E/}) { $kaputt=1; last; }
-	    }
+            foreach my $key (keys(%{$bombs})) {
+                my $currentdir = &Apache::lonnet::declutter("$targetdir/$disfilename");
+                if (($key) =~ m{^\Q$currentdir\E/}) { $kaputt=1; last; }
+            }
         }
 #
 # Get the metadata from that directory's default.meta to display titles
@@ -522,9 +531,9 @@ sub putresource {
     my $pubstatus = 'unpublished';
     my $status=&mt('Unpublished');
     my $css_class='LC_browser_file';
-    my $title='&nbsp;';
+    my $title='';
     my $publish_button=&mt('Publish');
-    my $cstr_dir = $r->dir_config('lonDocRoot').'/priv/'.$udom.'/'.$uname.'/'.$thisdisfn.'/';
+    my $cstr_dir = $r->dir_config('lonDocRoot').'/priv'.$thisdisfn;
     my $linkfilename=&HTML::Entities::encode('/priv'.$thisdisfn.'/'.$filename,'<>&"');
 
     if (-e $resdir.'/'.$filename) {
@@ -584,30 +593,43 @@ sub putresource {
 	    $status=&mt('Modified').
 		'<br />'. $rights_status;
 	    if (&Apache::loncommon::fileembstyle(($filename=~/\.(\w+)$/)) eq 'ssi') {
-		$status.='<br /><a href="/adm/diff?filename='.$linkfilename.
-		    '&amp;versiontwo=priv" target="cat">'.&mt('Diffs').'</a>';
+		$status.='<br />'.
+                         &Apache::loncommon::modal_link(
+                             '/adm/diff?filename='.$linkfilename.'&amp;versiontwo=priv',
+                             &mt('Diffs'),600,500);
 	    }
 	} 
-
-	$title.="\n".'<br /><a href="'.$linkfilename.'.meta">'. 
-	    ($$bombs{$targetdir.'/'.$filename}?'<img src="/adm/lonMisc/bomb.gif" border="0" alt="'.&mt('bomb').'" />':&mt('Edit Metadata')).'</a>';
-
 	if (!$meta_same) {
 	    $title = &mt('Metadata Modified').'<br />'.$title.
-		'<br /><a href="/adm/diff?filename=/priv/'.$linkfilename.'.meta'.
-		'&amp;versiontwo=priv" target="cat">'.&mt('Metadata Diffs').'</a>';
-	    $title.="\n".'<br /><a href="/adm/retrieve?filename='.$linkfilename.'.meta" target="_parent">'.&mt('Retrieve Metadata').'</a>';
+		'<br />'.
+                &Apache::loncommon::modal_link(
+                    '/adm/diff?filename='.$linkfilename.'.meta'.'&amp;versiontwo=priv',
+                    &mt('Metadata Diffs'),600,500);
+	    $title.="\n".'<br />'.
+                &Apache::loncommon::modal_link(
+                    '/adm/retrieve?filename='.$linkfilename.'.meta&amp;inhibitmenu=yes&amp;add_modal=yes',
+                    &mt('Retrieve Metadata'),600,500);
 	}
-	$status.="\n".'<br /><a href="/adm/retrieve?filename='.$linkfilename.'" target="_parent">'.&mt('Retrieve').'</a>';
-    }
+	$status.="\n".'<br />'.
+             &Apache::loncommon::modal_link(
+                 '/adm/retrieve?filename='.$linkfilename.'&amp;inhibitmenu=yes&amp;add_modal=yes',&mt('Retrieve'),600,500);
+    }
+    # Allow editing metadata of published and unpublished resources
+    $title .= "\n".'<br />' if ($title);
+    $title .= '<a href="'.$linkfilename.'.meta">'.
+              ($$bombs{&Apache::lonnet::declutter($targetdir.'/'.$filename)}?
+                  '<img src="/adm/lonMisc/bomb.gif" border="0" alt="'.&mt('bomb').'" />':
+                  &mt('Edit Metadata')).
+              '</a>';
+
     my $editlink='';
     my $editlink2='';
     if ($filename=~/\.(xml|html|htm|xhtml|xhtm|sty)$/) {
-	$editlink=' <br />(<a href="'.$linkdir.'/'.$filename.'?forceedit=1" target="_parent">'.&mt('Edit').'</a>)';
+	$editlink=' <br />(<a href="'.$linkdir.'/'.$filename.'?editmode=Edit&amp;problemmode=edit">'.&mt('Edit').'</a>)';
     }
     if ($filename=~/$LONCAPA::assess_re/) {
-	$editlink=' (<a href="'.$linkdir.'/'.$filename.'?forceedit=1" target="_parent">'.&mt('EditXML').'</a>)';
-	$editlink2=' <br />(<a href="'.$linkdir.'/'.$filename.'?forceColoredit=1" target="_parent">'.&mt('Edit').'</a>)';
+	$editlink=' (<a href="'.$linkdir.'/'.$filename.'?editmode=Edit&amp;problemmode=editxml">'.&mt('EditXML').'</a>)';
+	$editlink2=' <br />(<a href="'.$linkdir.'/'.$filename.'?editmode=Edit&amp;problemmode=edit">'.&mt('Edit').'</a>)';
     }
     if ($filename=~/\.(problem|exam|quiz|assess|survey|form|library|xml|html|htm|xhtml|xhtm|sty)$/) {
 	$editlink.=' (<a href="/adm/cleanup?filename='.$linkfilename.'" target="_parent">'.&mt('Clean Up').')</a>';
@@ -693,7 +715,7 @@ __END__
 
 =head1 NAME
 
-Apache::lonpubdir - Construction space directory lister
+Apache::lonpubdir - Authoring space directory lister
 
 =head1 SYNOPSIS
@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
-# Construction Space Directory Lister
+# Authoring Space Directory Lister
 #